@@ -261,7 +261,14 @@ def check_type(full_path):
     return None
   
 def gen_files(folder, ext = '', recursive=True, type='all') :
-  for f in glob.iglob(folder + '/**/*' + ext , recursive=recursive):
+  
+  folder_file_pattern = ''
+  if recursive == True:
+    folder_file_pattern = folder + '/**/*' + ext
+  else:
+    folder_file_pattern = folder + '/*' + ext
+  
+  for f in glob.iglob(folder_file_pattern, recursive=recursive):
     if os.name=='nt':  
       f = f.replace('\\','/').replace('//','/')
     if type=='all' : 
